@@ -1,10 +1,14 @@
-define (["xterm", "xtermjs-fit"], function(Terminal, fit) {
+define (["xterm"], function(Terminal) {
     "use strict";
-    function make_terminal(element, ws_url) {
+    function make_terminal(element, size, ws_url) {
         var ws = new WebSocket(ws_url);
-        Terminal.applyAddon(fit);
-        var term = new Terminal();
+        var term = new Terminal({
+          cols: size.cols,
+          rows: size.rows
+        });
         ws.onopen = function(event) {
+            ws.send(JSON.stringify(["set_size", size.rows, size.cols,
+                                        window.innerHeight, window.innerWidth]));
             term.on('data', function(data) {
                 ws.send(JSON.stringify(['stdin', data]));
             });
@@ -14,11 +18,7 @@ define (["xterm", "xtermjs-fit"], function(Terminal, fit) {
             });
             
             term.open(element);
-            term.fit();
-            // send the terminal size to the server.
-            ws.send(JSON.stringify(["set_size", term.rows, term.cols,
-                                        window.innerHeight, window.innerWidth]));
-
+            
             ws.onmessage = function(event) {
                 var json_msg = JSON.parse(event.data);
                 switch(json_msg[0]) {
