@@ -3,10 +3,9 @@ import os
 import terminado
 from ..utils import check_version
 
-if not check_version(terminado.__version__, '0.8.1'):
-    raise ImportError("terminado >= 0.8.1 required, found %s" % terminado.__version__)
+if not check_version(terminado.__version__, '0.3.3'):
+    raise ImportError("terminado >= 0.3.3 required, found %s" % terminado.__version__)
 
-from ipython_genutils.py3compat import which
 from terminado import NamedTermManager
 from tornado.log import app_log
 from notebook.utils import url_path_join as ujoin
@@ -14,13 +13,7 @@ from .handlers import TerminalHandler, TermSocket
 from . import api_handlers
 
 def initialize(webapp, notebook_dir, connection_url, settings):
-    if os.name == 'nt':
-        default_shell = 'powershell.exe'
-    else:
-        default_shell = which('sh')
-    shell = settings.get('shell_command',
-        [os.environ.get('SHELL') or default_shell]
-    )
+    shell = settings.get('shell_command', [os.environ.get('SHELL') or 'sh'])
     terminal_manager = webapp.settings['terminal_manager'] = NamedTermManager(
         shell_command=shell,
         extra_env={'JUPYTER_SERVER_ROOT': notebook_dir,
